"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.sha256 = exports.generateKey = exports.appleAttestation = void 0;
var _reactNative = require("react-native");
var _buffer = require("buffer");
const LINKING_ERROR = `The package 'react-native-attestation' doesn't seem to be linked. Make sure: \n\n` + _reactNative.Platform.select({
  ios: "- You have run 'pod install'\n",
  default: ''
}) + '- You rebuilt the app after installing the package\n' + '- You are not using Expo Go\n';

// @ts-expect-error
const isTurboModuleEnabled = global.__turboModuleProxy != null;
const AttestationModule = isTurboModuleEnabled ? require('./NativeAttestation').default : _reactNative.NativeModules.Attestation;
const Attestation = AttestationModule ? AttestationModule : new Proxy({}, {
  get() {
    throw new Error(LINKING_ERROR);
  }
});
const generateKey = async () => {
  return Attestation.generateKey();
};
exports.generateKey = generateKey;
const sha256 = async stringToHash => {
  const bytes = await Attestation.sha256(stringToHash);
  return _buffer.Buffer.from(bytes);
};
exports.sha256 = sha256;
const appleAttestation = async (keyId, challenge) => {
  const bytes = await Attestation.appleAttestation(keyId, challenge);
  return _buffer.Buffer.from(bytes);
};
exports.appleAttestation = appleAttestation;
//# sourceMappingURL=index.js.map